pub enum StartCommand {
Claude {
selector: String,
native_args: Vec<OsString>,
},
Codex {
selector: String,
native_args: Vec<OsString>,
},
}Variants
Claude
Start Claude with a provider selector without switching the global current provider
Fields
Codex
Start Codex with a provider selector without switching the global current provider